#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Backup Base command for Selfcheck."""

from iobase.xmldata import XmlConfNode
from fal_info import (FAL_SHARES_PATH, FAL_REPLICATION_PATH, ReqTypes, Results)
from fal_msginfo import Msg
from .baseselfchecker import (BaseSelfChecker, get__,
    NOT_SET_MSG, SUCCESS_MSG, RESULT_STR, SHARE_FOLDER_STR)

_ = get__("replication")

NAME_PATH = "name"
REPLICATION_PATH = "replication"
HOST_PATH = REPLICATION_PATH + "/host"
SHARE_PATH = REPLICATION_PATH + "/share"
RESULT_PATH = "result"
REPLI_ENABLE_SHARE_LIST_PATH = "sharelist/share/replication[@enable='true']/.."

SHARES_NODE_FMT = "<shares>%s</shares>"

REPLI_DST_HOST_STR = _(u"Replication destination host")
REPLI_DST_SHARE_STR = _(u"Replication destination share folder")

RESULT_FMT = SHARE_FOLDER_STR + ": %s\n" + \
  "--" + REPLI_DST_HOST_STR + ": %s\n" + \
  "--" + REPLI_DST_SHARE_STR + ": %s\n" + \
  "--" + RESULT_STR + ": %s\n" + \
  "\n"


RESULT_CODE_MSG_DICT = {
    "5": Msg.ERR_REPLICATION_AUTH,
    "20": Msg.ERR_REPLICATION_SIGNAL,
    "30": Msg.ERR_REPLICATION_TIMEOUT}

SUCCESS_RESULT_CODE = "0"


class SelfChecker(BaseSelfChecker):

    CHECKER_NAME = "replication"

    def __check_repli(self, share_node):

        name = share_node.get_value(NAME_PATH)
        host = share_node.get_value(HOST_PATH)
        share = share_node.get_value(SHARE_PATH)

        result_entry = self._request(FAL_REPLICATION_PATH, ReqTypes.CHECK,
            XmlConfNode(SHARES_NODE_FMT % str(share_node)))

        check_result = result_entry.get().get_value(RESULT_PATH, "")

        if check_result == SUCCESS_RESULT_CODE:
            msg = SUCCESS_MSG
        else:
            msg_code = RESULT_CODE_MSG_DICT.get(
                check_result, Msg.ERR_REPLICATION_EXEC_CMD)
            msg = self._get_message(
                msg_code, {"name": name, "errcode": check_result})

        return RESULT_FMT % (name, host, share, msg)

    def selfcheck(self, check_xml=None):
        """Self Check."""

        self._set_processing()

        config_node = self._request(FAL_SHARES_PATH, ReqTypes.LOAD).get()

        result = ""

        for share_node in config_node.get_node_list(
            REPLI_ENABLE_SHARE_LIST_PATH):
            result += self.__check_repli(share_node)

        if not result:
            result = NOT_SET_MSG

        self._set_status(result)

        return True
