#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

from __future__ import with_statement

import os
import sys
from iobase.xmldata import XmlConfNode
from fal_info import (FAL_SHARES_PATH, FAL_FEATURES_PATH, ReqTypes)

# debpkg_utils.pyインポート用
sys.path.append(os.path.join(
    os.path.dirname(os.path.abspath(__file__)),
    os.path.pardir))

from debpkg_utils import *

import manualctrl


FUNC_VERSION = "1"
PACKAGE = "replication"

REMOVE_LIST = ["/mnt/data/conf/rsync_client"]

FEATURES_REQ_XML = ("<features><functionlist>" + 
        '<function version="%s">%s</function></functionlist></features>') % \
                (FUNC_VERSION, PACKAGE)


class ShareXmlConfModifier(BaseXmlConfModifier):

    FAL = FAL_SHARES_PATH

    class ShareServiceModifyInfo():
        PAR_XPATH = "sharelist/share"
        INSTALL_NODE_LIST = [XmlConfNode("""<replication enable="false">
            <host/><share/><username/><passwd/></replication>""")]
        REMOVE_XPATH_LIST = ["replication"]

    MODIFY_INFO_LIST = [ShareServiceModifyInfo]


def remove_fsevsync_targets():
    FILE = "/proc/fsevsync/targets"
    CMD = "DELALL:"

    with open(FILE, "wb") as file:
        file.write(CMD)


def add_function_for_features():
    """Add a entry of replication function to features's configuration."""

    try:
        request(FAL_FEATURES_PATH, ReqTypes.ADD, FEATURES_REQ_XML)
    except:
        # Ignore error
        pass


def delete_function_for_features():
    """Delete a entry of replication function from features's configuration."""

    try:
        request(FAL_FEATURES_PATH, ReqTypes.DELETE, FEATURES_REQ_XML)
    except:
        # Ignore error
        pass


if __name__ == "__main__":
    share_ins = ShareXmlConfModifier()
    if sys.argv[1] == "postinst_configure_install":
        share_ins.install()
        msg_xml_modify_with_file(PACKAGE)
        manualctrl.install()
        add_function_for_features()

    elif sys.argv[1] == "postinst_configure_upgrade":
        # ここで既存の設定に対しての処理をする

        # upgradeの時はreplicationは注意。
        # update_real_confするとADDDIR:され、
        # 内蔵未マウント状態で初期同期開始される。
        # SUSPEND:してからupdate_real_confし、
        # RESUME:する必要あり。

        manualctrl.update()
        add_function_for_features()

    elif sys.argv[1] == "prerm_remove":
        share_ins.remove()
        remove_fsevsync_targets()
        remove_files(REMOVE_LIST)
        manualctrl.uninstall()
        delete_function_for_features()

    elif sys.argv[1] == "prerm_upgrade":
        # upgrade時は既存の設定を削除しない
        delete_function_for_features()
