# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from django.utils.translation import ugettext as _
from project.forms.fields.checkbox import CheckboxField
from project.forms.fields.text import TextField
from project.forms.fields.password import PasswordField
from project.forms.fields.extras.validators.fal import FALValidator
from fal_validinfo import (LanDiskPass, Fqdn,
    ShareName, UserName)
try:
    import replicationextras
    reload(replicationextras)
    from replicationextras import ATTRS, INITIAL
except:
    ATTRS = {}
    INITIAL = {}


class DestHostValidator(FALValidator):
    validator = Fqdn.VALIDATOR
    options = {}


class DestShareValidator(FALValidator):
    validator = ShareName.VALIDATOR
    options = {"exempt_duplicate": "true", "exempt_uplow": "true"}


class DestUserNameValidator(FALValidator):
    validator = UserName.VALIDATOR
    options = {}


class DestPasswdValidator(FALValidator):
    validator = LanDiskPass.VALIDATOR
    options = {}


fields = {
    'replication': CheckboxField(
        attrs=ATTRS.get('replication', {}),
        label=_(u'Replication'),
        #initial=False,
        initial=INITIAL.get('replication'),
        validators=[]),
    'repli_dest_host': TextField(
        attrs=ATTRS.get('repli_dest_host', {}),
        label=_(u'Replication Destination Host'),
        #initial="",
        initial=INITIAL.get('repli_dest_host'),
        required=False,
        validators=[DestHostValidator()],
        max_length=Fqdn.MAX_LENGTH,
        min_length=Fqdn.MIN_LENGTH),
    'repli_dest_share': TextField(
        attrs=ATTRS.get('repli_dest_share', {}),
        label=_(u'Replication Destination Share'),
        #initial="",
        initial=INITIAL.get('repli_dest_share'),
        required=False,
        validators=[DestShareValidator()],
        max_length=ShareName.MAX_LENGTH,
        min_length=ShareName.MIN_LENGTH),
    'repli_dest_user': TextField(
        label=_(u'Replication Destination User'),
        initial="",
        required=False,
        validators=[DestUserNameValidator()],
        max_length=UserName.MAX_LENGTH,
        min_length=UserName.MIN_LENGTH),
    'repli_dest_passwd': PasswordField(
        attrs=ATTRS.get('repli_dest_passwd', {}),
        label=_(u'Replication Destination Password'),
        #initial="",
        initial=INITIAL.get('repli_dest_passwd'),
        required=False,
        validators=[DestPasswdValidator()],
        max_length=LanDiskPass.MAX_LENGTH,
        min_length=LanDiskPass.MIN_LENGTH),
    }
